==> haskell-libffi-0.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libffi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libffi
version: 0.1
id: libffi-0.1-9BCKWMADPWqE9LZxtKazhb
key: libffi-0.1-9BCKWMADPWqE9LZxtKazhb
license: BSD3
copyright: Remi Turk 2008-2009
maintainer: remi.turk@gmail.com
stability: alpha
synopsis: A binding to libffi
description:
    A binding to libffi, allowing C functions of types only known at runtime to be called from Haskell.
category: Foreign
author: Remi Turk
exposed: True
indefinite: False
exposed-modules:
    Foreign.LibFFI Foreign.LibFFI.Base Foreign.LibFFI.FFITypes
    Foreign.LibFFI.Internal Foreign.LibFFI.Types
abi: 77ead549066d8e9bf60750f77fa02fe5
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/libffi-0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/libffi-0.1
              /usr/lib/../lib
dynamic-library-dirs: /usr/lib /usr/lib/../lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/libffi-0.1
hs-libraries: HSlibffi-0.1-9BCKWMADPWqE9LZxtKazhb
extra-libraries:
    ffi ffi
include-dirs: /usr/lib/libffi-3.2.1/include
includes:
    ffi.h ffitarget.h
depends:
    base-4.10.1.0 bytestring-0.10.8.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-libffi/html/libffi.haddock
haddock-html: /usr/share/doc/haskell-libffi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libffi-0.1-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libffi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libffi
version: 0.1
id: libffi-0.1-KciznLKKFMTLZ0dw70VJSt
key: libffi-0.1-KciznLKKFMTLZ0dw70VJSt
license: BSD-3-Clause
copyright: Remi Turk 2008-2009
maintainer: remi.turk@gmail.com
author: Remi Turk
stability: alpha
synopsis: A binding to libffi
description:
    A binding to libffi, allowing C functions of types only known at runtime to be called from Haskell.
category: Foreign
abi: 2e071b3d7e1768dc71ce2b5f44c51a99
exposed: True
exposed-modules:
    Foreign.LibFFI Foreign.LibFFI.Base Foreign.LibFFI.FFITypes
    Foreign.LibFFI.Internal Foreign.LibFFI.Types
import-dirs: /usr/lib/ghc-8.4.2/site-local/libffi-0.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/libffi-0.1
              /usr/lib/../lib
dynamic-library-dirs: /usr/lib /usr/lib/../lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/libffi-0.1
hs-libraries: HSlibffi-0.1-KciznLKKFMTLZ0dw70VJSt
extra-libraries:
    ffi ffi
include-dirs: /usr/lib/libffi-3.2.1/include
includes:
    ffi.h ffitarget.h
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
haddock-interfaces: /usr/share/doc/haskell-libffi/html/libffi.haddock
haddock-html: /usr/share/doc/haskell-libffi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
